#!/bin/sh -e

SOURCE=jrfd
ORIENT=landscape
TERM=""


short_usage ()
{
    echo "Usage : $0 [action] [file]"
    echo "  Where actions are :"
    echo "    --help, port, land, pdf, html, rtf, print, circuit,"
    echo "    doc_circuit, ex_circuit, ex_lettre, csv2tex, clean, cleanall"
}

usage ()
{
    echo "Usage : $0 [action] [file]"
    echo "  Where actions are :"
    echo "    port          portrait orientation"
    echo "    land          lanscape orientation"
    echo "    pdf           make a pdf file"
    echo "    html          make an html file in directory ./document/"
    echo "    rtf           make an rtf file compatible with MSWord"
    echo "    print         print document on printer"
    echo "    circuit       compile <file>.m4 to <file>.tex for electronic circuits"
    echo "    doc_circuit   display the documentation for electronic circuits drawing"
    echo "    ex_circuit    copy an example of electronic circuit in current directory"
    echo "    ex_lettre     copy an example of letter in current directory (lettre.tex)"
    echo "    csv2tex       convert <file>.csv spreadsheet into <file>.tex"
    echo "    clean         clean all unuseful files"
    echo "    cleanall      clean all unuseful files and all files make by $0"
}


make_clean ()
{
    rm -f *.dvi *.log *.aux *.bak *.toc *~ *.tmp *.pic
}

make_circuit_m4_2_tex ()
{
    m4 /usr/local/circuit_macros/libcct.m4 $1.m4 > $1.pic
    gpic -t $1.pic > $1.tex
}


make_csv2tex ()
{
    NAME=$(basename $1 csv)tex
    echo "Convert $1 in $NAME"
    echo "\begin{tabular}{|c|c|c|c|c|c|c|c|c|c|c|c|c|c|c|c|c|c|c|c|c|c|c|c|c|c|c|}" > $NAME
    echo "\hline" >> $NAME
    cat $1 | tr '\11' '&' | sed -e 's/\&/ \& /g' | sed -e 's/$/\\\\ \\hline/g' | tr -d '"' >> $NAME
    echo >> $NAME
    echo "\end{tabular}" >> $NAME
}




make_dvi ()
{
    $TERM latex $SOURCE
    $TERM dvips $SOURCE -o -t $ORIENT -t a4
}



case $1 in
    -h)
	short_usage
	;;

    --help)
	usage
	;;

    port)
	cat cpl_tex.sh | sed -e 's/O[R]IENT=landscape/OR\IENT=portrait/g' > cpl_tex.sh.tmp
	mv cpl_tex.sh.tmp cpl_tex.sh
	chmod a+x cpl_tex.sh

	cat format.tex | sed -e 's/landscape/portrait/g' > format.tex.tmp
	mv format.tex.tmp format.tex
	;;

    land)
	cat cpl_tex.sh | sed -e 's/O[R]IENT=portrait/OR\IENT=landscape/g' > cpl_tex.sh.tmp
	mv cpl_tex.sh.tmp cpl_tex.sh
	chmod a+x cpl_tex.sh

	cat format.tex | sed -e 's/portrait/landscape/g' > format.tex.tmp
	mv format.tex.tmp format.tex
	;;

    pdf)
	make_dvi
	$TERM ps2pdf $SOURCE.ps
	;;
    html)
	$TERM latex2html $SOURCE.tex
	;;
    rtf)
	$TERM latex2rtf -l $SOURCE.tex -o $SOURCE.rtf
	;;
    print)
	make_dvi
	lpr $SOURCE.ps
	;;

    circuit)
	make_circuit_m4_2_tex $2
	;;

    doc_circuit)
	gv /usr/local/circuit_macros/doc/man.ps &
	;;

    ex_circuit)
	cp /usr/local/circuit_macros/examples/quick.m4 .
	;;

    ex_lettre)
	cp /home/phil/Latex/lettre.tex .
	;;

    csv2tex)
	make_csv2tex $2
	;;

    clean)
	make_clean
	;;
    cleanall)
	make_clean
	rm -rf *.ps *.pdf *~ document *.rtf
	;;
    "")
	make_dvi
	gv $SOURCE.ps
	;;

    *)
	short_usage
	;;
esac
